@@ -1,3 +1,3 @@
 from nmec import NMEC
 test = NMEC()
-test.example()
\ No newline at end of file
+print(test.example())
\ No newline at end of file
