@@ -1,5 +1,6 @@
-from .Model import Model
+from Model import Model
 import pandas as pd
+import numpy as np
 from sklearn.linear_model import LinearRegression
 
 
@@ -56,7 +57,6 @@ class TOWTModel(Model):
             Specific model name.
             Options are: TOW, TOWT
             Upper or lower case is accepted. Default is TOWT.
-            
         Returns
         -------
         None.
@@ -73,7 +73,7 @@ class TOWTModel(Model):
         self.tow_train_cols = []
         self.knot_temps = knot_temps
         self.occ_threshold = occ_threshold
-        
+
         if self.model_name not in ["TOWT", "TOW"]:
             raise ValueError("Unknonwn model type: " + self.model_name + ". "
                              "Please specify model_name as TOW or TOWT.")
@@ -104,19 +104,19 @@ class TOWTModel(Model):
             self.knot_temps = knot_temps
 
         if interval is None:
-            interval = str(self.min_interval)
-        
+            interval = self.min_interval
+
         min_available_interval_num = self.interval_tiers[self.min_interval]
-        desired_interval_num = self.interval_tiers[str(interval)]
+        desired_interval_num = self.interval_tiers[interval]
 
         if min_available_interval_num > desired_interval_num:
             self.df = self.group_interval(time_interval=interval,
                                           time_col=self.timestamp_col)
-         
+
         if min_available_interval_num < desired_interval_num:
             raise ValueError(
-                'Desired interval: ' + interval + 
-                ' is unavailable. Highest granularity is ' + 
+                'Desired interval: ' + interval +
+                ' is unavailable. Highest granularity is ' +
                 self.min_interval + '.')
 
         # Check if time_interval is monthly
@@ -124,7 +124,7 @@ class TOWTModel(Model):
             raise ValueError(
                 'Inferred time interval is monthly. The TOWT'
                 ' algorithm expects hourly or daily data.')
-        
+
         self.model_interval = interval
 
         # Define knot temp vars and tow vars
@@ -156,6 +156,11 @@ class TOWTModel(Model):
                                 == 1, self.x_train_cols]
         occ_y_train = train.loc[train[self.occupancy_col]
                                 == 1, self.dependent_col]
+        occ_check = occ_x_train.loc[:, tow_vars.columns].sum() != 0
+        occ_x_train[occ_check.index[occ_check].tolist()[-1]] = 0
+        zero_check = occ_x_train.loc[:, tow_vars.columns].sum() == 0
+        occ_x_train.drop(columns=zero_check.index[zero_check].tolist(),
+                         inplace=True)
         occ_model = LinearRegression().fit(occ_x_train, occ_y_train)
         self.occ_model = occ_model
 
@@ -165,6 +170,11 @@ class TOWTModel(Model):
                                       == 0, self.x_train_cols]
             unocc_y_train = train.loc[train[self.occupancy_col]
                                       == 0, self.dependent_col]
+            unocc_check = unocc_x_train.loc[:, tow_vars.columns].sum() != 0
+            unocc_x_train[unocc_check.index[unocc_check].tolist()[-1]] = 0
+            zero_check = unocc_x_train.loc[:, tow_vars.columns].sum() == 0
+            unocc_x_train.drop(columns=zero_check.index[zero_check].tolist(),
+                               inplace=True)
             unocc_model = LinearRegression().fit(unocc_x_train, unocc_y_train)
             self.unocc_model = unocc_model
 
@@ -194,7 +204,7 @@ class TOWTModel(Model):
         '''
         return(main)
 
-    def predict(self, df, occ_model=None, unocc_model=None):
+    def predict(self, df):
         """
         Predict method for TOWT and TOW models.
         Parameters
@@ -202,29 +212,13 @@ class TOWTModel(Model):
         df : Pandas DataFrame
             Dataframe consisting of at least time['time'] and occupancy['occ'].
             Temp is needed for TOWT.
-        occ_model : sklearn LinearRegression object, optional
-            Regression object for occipied model. This is required. If None,
-            will assume it is an object attribute.
-        unocc_model : sklearn LinearRegression object, optional
-            Regression object for unoccipied model. The default is None.
-            If None, will assume it is an object attribute. If object attribute
-            is also None, will assume there is no unoccupied model to predict
-            on.
-
         Returns
         -------
         The main pandas dataframe with the predictions attached to it.
         """
 
-        # Check model objects
-        if (occ_model != self.occ_model) & (occ_model is not None):
-            self.occ_model = occ_model
-        if (unocc_model != self.unocc_model) & (unocc_model is not None):
-            self.unocc_model = unocc_model
-        time_interval = self.infer_interval(df)
-
         # Check if time_interval is monthly
-        if time_interval == "Monthly":
+        if self.model_interval == "Monthly":
             raise ValueError(
                 'Inferred time interval is monthly. The TOWT'
                 ' algorithm expects hourly or daily data.')
@@ -235,7 +229,7 @@ class TOWTModel(Model):
         if self.model_name == "TOWT":
             temp_vars, used_knot_temps = self.define_temp_vars(
                 df, self.knot_temps)
-        tow_vars = self.define_tow_vars(df, time_interval)
+        tow_vars = self.define_tow_vars(df, self.model_interval)
 
         main = pd.concat([df, temp_vars, tow_vars], axis=1)
         pred = main.dropna().copy()
@@ -245,16 +239,24 @@ class TOWTModel(Model):
             pred.drop(columns=['time'], inplace=True)
 
         # Predict
-        occ_x_pred = pred.loc[pred['occ'] == 1, pred.columns != 'load']
-        occ_x_pred.drop(columns='occ', inplace=True)
-        occ_x_pred['predict'] = occ_model.predict(occ_x_pred)
-        if pred['occ'].nunique() > 1:
-            unocc_x_pred = pred.loc[pred['occ'] == 0, pred.columns != 'load']
-            unocc_x_pred.drop(columns='occ', inplace=True)
-            unocc_x_pred['predict'] = unocc_model.predict(unocc_x_pred)
+        occ_x_pred = pd.DataFrame()
+        unocc_x_pred = pd.DataFrame()
+        if 1 in df[self.occupancy_col].unique():
+            occ_x_pred = pred.loc[pred[self.occupancy_col] == 1,
+                                  pred.columns != self.dependent_col]
+            occ_x_pred.drop(columns=self.occupancy_col, inplace=True)
+            occ_x_pred = occ_x_pred.loc[:, self.occ_model.feature_names_in_]
+            occ_x_pred['predict'] = self.occ_model.predict(occ_x_pred)
+        if 0 in df[self.occupancy_col].unique():
+            unocc_x_pred = pred.loc[pred[self.occupancy_col] == 0,
+                                    pred.columns != self.dependent_col]
+            unocc_x_pred.drop(columns=self.occupancy_col, inplace=True)
+            unocc_x_pred = unocc_x_pred.loc[:,
+                                            self.unocc_model.feature_names_in_]
+            unocc_x_pred['predict'] = self.unocc_model.predict(unocc_x_pred)
 
         pred = pd.concat([occ_x_pred, unocc_x_pred], axis=0)
-        out = pd.concat([main, pred['predict']], axis=1)
+        out = pd.concat([df, pred['predict']], axis=1)
         return(out)
 
     def temp0(self, temp, knot_temp):
@@ -344,8 +346,8 @@ class TOWTModel(Model):
         max_temp = df['temp'].max()
 
         # Drop outside knot temperature bounds if redundant
-        knot_temps = [x for x in knot_temps if x > min_temp]
-        knot_temps = [x for x in knot_temps if x < max_temp]
+        # knot_temps = [x for x in knot_temps if x > min_temp]
+        # knot_temps = [x for x in knot_temps if x < max_temp]
 
         # Sort knot temperatures from least to greatest
         knot_temps.sort()
@@ -386,18 +388,24 @@ class TOWTModel(Model):
             Dataframe containing indicator variables for time of week.
         """
         if time_interval.upper() == 'DAILY':
+            out_init = pd.DataFrame(0, index=np.arange(df.shape[0]),
+                                    columns=['tow_'+str(x) for x in range(7)])
             dow = df['time'].dt.dayofweek
             tow_vars = pd.get_dummies(dow, prefix="tow")
-            return(tow_vars)
+            out_init.loc[:, tow_vars.columns] = tow_vars
+            return(out_init)
 
         elif time_interval.upper() == 'HOURLY':
+            out_init = pd.DataFrame(0, index=np.arange(df.shape[0]),
+                                    columns=['tow_'+str(x) for x in range(168)])
             dow = df['time'].dt.dayofweek
             hour = df['time'].dt.hour
             tow = dow*24 + hour
             tow_vars = pd.get_dummies(tow, prefix="tow")
-            return(tow_vars)
+            out_init.loc[:, tow_vars.columns] = tow_vars
+            return(out_init)
 
         else:
             raise ValueError(
                 "Time interval supplied expected 'daily' or 'hourly'. "
-                "Neither of those were given.")
+                "Neither of those were given.")
\ No newline at end of file
